<img src="https://www.kubeflow.org/images/logo.svg" width="100">

## Overview of Kubeflow Fairing

Kubeflow Fairing is a Python package that streamlines the process of building,
training, and deploying machine learning (ML) models in a hybrid cloud
environment. By using Kubeflow Fairing and adding a few lines of code, you can
run your ML training job locally or in the cloud, directly from Python code or
a Jupyter notebook. After your training job is complete, you can use Kubeflow
Fairing to deploy your trained model as a prediction endpoint.

## Documentation

To learn how Kubeflow Fairing streamlines the process of training and deploying
ML models in the cloud, read the [Kubeflow Fairing
documentation][fairing-overview]. 

To learn the Kubeflow Fairing SDK API, read the [HTML documentation][html-doc].

To quick start, you can run the [E2E MNIST sample](examples/mnist).

[fairing-overview]: https://www.kubeflow.org/docs/fairing/fairing-overview/
[html-doc]: https://kubeflow-fairing.readthedocs.io/en/latest/index.html

